Class: TZInfo::Timestamp

Inherits:
Object
  • Object
show all
Defined in:
lib/logstash/inputs/tzinfo_jruby_patch.rb

Overview

A time represented as an Integer number of seconds since 1970-01-01 00:00:00 UTC (ignoring leap seconds), the fraction through the second (sub_second as a Rational) and an optional UTC offset. Like Ruby's Time class, Timestamp can distinguish between a local time with a zero offset and a time specified explicitly as UTC.